==> kubernetes-model-admissionregistration-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/MatchResourcesFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

 /**
  * Generated
  */
public interface MatchResourcesFluent<A extends MatchResourcesFluent<A>> extends Fluent<A>{
  public A addToExcludeResourceRules(Integer index,NamedRuleWithOperations item);
  public A setToExcludeResourceRules(Integer index,NamedRuleWithOperations item);
  public A addToExcludeResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... items);
  public A addAllToExcludeResourceRules(Collection<NamedRuleWithOperations> items);
  public A removeFromExcludeResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... items);
  public A removeAllFromExcludeResourceRules(Collection<NamedRuleWithOperations> items);
  public A removeMatchingFromExcludeResourceRules(Predicate<NamedRuleWithOperationsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExcludeResourceRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NamedRuleWithOperations> getExcludeResourceRules();
  public List<NamedRuleWithOperations> buildExcludeResourceRules();
  public NamedRuleWithOperations buildExcludeResourceRule(Integer index);
  public NamedRuleWithOperations buildFirstExcludeResourceRule();
  public NamedRuleWithOperations buildLastExcludeResourceRule();
  public NamedRuleWithOperations buildMatchingExcludeResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public Boolean hasMatchingExcludeResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public A withExcludeResourceRules(List<NamedRuleWithOperations> excludeResourceRules);
  public A withExcludeResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... excludeResourceRules);
  public Boolean hasExcludeResourceRules();
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> addNewExcludeResourceRule();
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> addNewExcludeResourceRuleLike(NamedRuleWithOperations item);
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> setNewExcludeResourceRuleLike(Integer index,NamedRuleWithOperations item);
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> editExcludeResourceRule(Integer index);
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> editFirstExcludeResourceRule();
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> editLastExcludeResourceRule();
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> editMatchingExcludeResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public String getMatchPolicy();
  public A withMatchPolicy(String matchPolicy);
  public Boolean hasMatchPolicy();
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getNamespaceSelector();
  public LabelSelector buildNamespaceSelector();
  public A withNamespaceSelector(LabelSelector namespaceSelector);
  public Boolean hasNamespaceSelector();
  public MatchResourcesFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
  public MatchResourcesFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(LabelSelector item);
  public MatchResourcesFluent.NamespaceSelectorNested<A> editNamespaceSelector();
  public MatchResourcesFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
  public MatchResourcesFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(LabelSelector item);
  
  /**
   * This method has been deprecated, please use method buildObjectSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getObjectSelector();
  public LabelSelector buildObjectSelector();
  public A withObjectSelector(LabelSelector objectSelector);
  public Boolean hasObjectSelector();
  public MatchResourcesFluent.ObjectSelectorNested<A> withNewObjectSelector();
  public MatchResourcesFluent.ObjectSelectorNested<A> withNewObjectSelectorLike(LabelSelector item);
  public MatchResourcesFluent.ObjectSelectorNested<A> editObjectSelector();
  public MatchResourcesFluent.ObjectSelectorNested<A> editOrNewObjectSelector();
  public MatchResourcesFluent.ObjectSelectorNested<A> editOrNewObjectSelectorLike(LabelSelector item);
  public A addToResourceRules(Integer index,NamedRuleWithOperations item);
  public A setToResourceRules(Integer index,NamedRuleWithOperations item);
  public A addToResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... items);
  public A addAllToResourceRules(Collection<NamedRuleWithOperations> items);
  public A removeFromResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... items);
  public A removeAllFromResourceRules(Collection<NamedRuleWithOperations> items);
  public A removeMatchingFromResourceRules(Predicate<NamedRuleWithOperationsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResourceRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NamedRuleWithOperations> getResourceRules();
  public List<NamedRuleWithOperations> buildResourceRules();
  public NamedRuleWithOperations buildResourceRule(Integer index);
  public NamedRuleWithOperations buildFirstResourceRule();
  public NamedRuleWithOperations buildLastResourceRule();
  public NamedRuleWithOperations buildMatchingResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public Boolean hasMatchingResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public A withResourceRules(List<NamedRuleWithOperations> resourceRules);
  public A withResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... resourceRules);
  public Boolean hasResourceRules();
  public MatchResourcesFluent.ResourceRulesNested<A> addNewResourceRule();
  public MatchResourcesFluent.ResourceRulesNested<A> addNewResourceRuleLike(NamedRuleWithOperations item);
  public MatchResourcesFluent.ResourceRulesNested<A> setNewResourceRuleLike(Integer index,NamedRuleWithOperations item);
  public MatchResourcesFluent.ResourceRulesNested<A> editResourceRule(Integer index);
  public MatchResourcesFluent.ResourceRulesNested<A> editFirstResourceRule();
  public MatchResourcesFluent.ResourceRulesNested<A> editLastResourceRule();
  public MatchResourcesFluent.ResourceRulesNested<A> editMatchingResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ExcludeResourceRulesNested<N> extends Nested<N>,NamedRuleWithOperationsFluent<MatchResourcesFluent.ExcludeResourceRulesNested<N>>{
    public N and();
    public N endExcludeResourceRule();
    
  }
  public interface NamespaceSelectorNested<N> extends Nested<N>,LabelSelectorFluent<MatchResourcesFluent.NamespaceSelectorNested<N>>{
    public N and();
    public N endNamespaceSelector();
    
  }
  public interface ObjectSelectorNested<N> extends Nested<N>,LabelSelectorFluent<MatchResourcesFluent.ObjectSelectorNested<N>>{
    public N and();
    public N endObjectSelector();
    
  }
  public interface ResourceRulesNested<N> extends Nested<N>,NamedRuleWithOperationsFluent<MatchResourcesFluent.ResourceRulesNested<N>>{
    public N and();
    public N endResourceRule();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/MatchResourcesFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

 /**
  * Generated
  */
public interface MatchResourcesFluent<A extends MatchResourcesFluent<A>> extends Fluent<A>{
  public A addToExcludeResourceRules(int index,NamedRuleWithOperations item);
  public A setToExcludeResourceRules(int index,NamedRuleWithOperations item);
  public A addToExcludeResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... items);
  public A addAllToExcludeResourceRules(Collection<NamedRuleWithOperations> items);
  public A removeFromExcludeResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... items);
  public A removeAllFromExcludeResourceRules(Collection<NamedRuleWithOperations> items);
  public A removeMatchingFromExcludeResourceRules(Predicate<NamedRuleWithOperationsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExcludeResourceRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NamedRuleWithOperations> getExcludeResourceRules();
  public List<NamedRuleWithOperations> buildExcludeResourceRules();
  public NamedRuleWithOperations buildExcludeResourceRule(int index);
  public NamedRuleWithOperations buildFirstExcludeResourceRule();
  public NamedRuleWithOperations buildLastExcludeResourceRule();
  public NamedRuleWithOperations buildMatchingExcludeResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public Boolean hasMatchingExcludeResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public A withExcludeResourceRules(List<NamedRuleWithOperations> excludeResourceRules);
  public A withExcludeResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... excludeResourceRules);
  public Boolean hasExcludeResourceRules();
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> addNewExcludeResourceRule();
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> addNewExcludeResourceRuleLike(NamedRuleWithOperations item);
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> setNewExcludeResourceRuleLike(int index,NamedRuleWithOperations item);
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> editExcludeResourceRule(int index);
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> editFirstExcludeResourceRule();
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> editLastExcludeResourceRule();
  public MatchResourcesFluent.ExcludeResourceRulesNested<A> editMatchingExcludeResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public String getMatchPolicy();
  public A withMatchPolicy(String matchPolicy);
  public Boolean hasMatchPolicy();
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getNamespaceSelector();
  public LabelSelector buildNamespaceSelector();
  public A withNamespaceSelector(LabelSelector namespaceSelector);
  public Boolean hasNamespaceSelector();
  public MatchResourcesFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
  public MatchResourcesFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(LabelSelector item);
  public MatchResourcesFluent.NamespaceSelectorNested<A> editNamespaceSelector();
  public MatchResourcesFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
  public MatchResourcesFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(LabelSelector item);
  
  /**
   * This method has been deprecated, please use method buildObjectSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getObjectSelector();
  public LabelSelector buildObjectSelector();
  public A withObjectSelector(LabelSelector objectSelector);
  public Boolean hasObjectSelector();
  public MatchResourcesFluent.ObjectSelectorNested<A> withNewObjectSelector();
  public MatchResourcesFluent.ObjectSelectorNested<A> withNewObjectSelectorLike(LabelSelector item);
  public MatchResourcesFluent.ObjectSelectorNested<A> editObjectSelector();
  public MatchResourcesFluent.ObjectSelectorNested<A> editOrNewObjectSelector();
  public MatchResourcesFluent.ObjectSelectorNested<A> editOrNewObjectSelectorLike(LabelSelector item);
  public A addToResourceRules(int index,NamedRuleWithOperations item);
  public A setToResourceRules(int index,NamedRuleWithOperations item);
  public A addToResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... items);
  public A addAllToResourceRules(Collection<NamedRuleWithOperations> items);
  public A removeFromResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... items);
  public A removeAllFromResourceRules(Collection<NamedRuleWithOperations> items);
  public A removeMatchingFromResourceRules(Predicate<NamedRuleWithOperationsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResourceRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NamedRuleWithOperations> getResourceRules();
  public List<NamedRuleWithOperations> buildResourceRules();
  public NamedRuleWithOperations buildResourceRule(int index);
  public NamedRuleWithOperations buildFirstResourceRule();
  public NamedRuleWithOperations buildLastResourceRule();
  public NamedRuleWithOperations buildMatchingResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public Boolean hasMatchingResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public A withResourceRules(List<NamedRuleWithOperations> resourceRules);
  public A withResourceRules(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.NamedRuleWithOperations... resourceRules);
  public Boolean hasResourceRules();
  public MatchResourcesFluent.ResourceRulesNested<A> addNewResourceRule();
  public MatchResourcesFluent.ResourceRulesNested<A> addNewResourceRuleLike(NamedRuleWithOperations item);
  public MatchResourcesFluent.ResourceRulesNested<A> setNewResourceRuleLike(int index,NamedRuleWithOperations item);
  public MatchResourcesFluent.ResourceRulesNested<A> editResourceRule(int index);
  public MatchResourcesFluent.ResourceRulesNested<A> editFirstResourceRule();
  public MatchResourcesFluent.ResourceRulesNested<A> editLastResourceRule();
  public MatchResourcesFluent.ResourceRulesNested<A> editMatchingResourceRule(Predicate<NamedRuleWithOperationsBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ExcludeResourceRulesNested<N> extends Nested<N>,NamedRuleWithOperationsFluent<MatchResourcesFluent.ExcludeResourceRulesNested<N>>{
    public N and();
    public N endExcludeResourceRule();
    
  }
  public interface NamespaceSelectorNested<N> extends Nested<N>,LabelSelectorFluent<MatchResourcesFluent.NamespaceSelectorNested<N>>{
    public N and();
    public N endNamespaceSelector();
    
  }
  public interface ObjectSelectorNested<N> extends Nested<N>,LabelSelectorFluent<MatchResourcesFluent.ObjectSelectorNested<N>>{
    public N and();
    public N endObjectSelector();
    
  }
  public interface ResourceRulesNested<N> extends Nested<N>,NamedRuleWithOperationsFluent<MatchResourcesFluent.ResourceRulesNested<N>>{
    public N and();
    public N endResourceRule();
    
  }
  
}
